@@ -4,6 +4,7 @@ timeVariation <- function(mydata,
                           normalise = FALSE,
                           ylab = pollutant,
                           xlab = c("hour", "hour", "month", "weekday"),
+                          ylim = NA,
                           name.pol = pollutant,
                           type = "default",
                           group = NULL,
@@ -34,6 +35,12 @@ timeVariation <- function(mydata,
         if (group %in% pollutant) stop("Cannot have group the same as a pollutant name.")
     }
 
+    ## check to see if type = "variable" (word used in code, so change)
+    if (type == "variable") {
+        mydata <- rename(mydata, c(variable = "tempVar"))
+        type <- "tempVar"
+    }
+
     ## if group is present, need to add that list of variables
     if (!missing(group)){
         
@@ -46,8 +53,8 @@ timeVariation <- function(mydata,
     
     ## data checks
     mydata <- checkPrep(mydata, vars, type)
-    if (!missing(group))  mydata <- cutData(mydata, group) 
-    mydata <- cutData(mydata, type)
+    if (!missing(group))  mydata <- cutData(mydata, group, ...) 
+    mydata <- cutData(mydata, type, ...)
 
     mydata <- na.omit(mydata)
 
@@ -154,6 +161,8 @@ timeVariation <- function(mydata,
     
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ hour | ", temp, sep = ""))
+
+    if (missing(ylim)) ylim.hour <- rng(data.hour) else ylim.hour <- ylim
     
     hour <- xyplot(myform,  data = data.hour, groups = variable,
                    as.table = TRUE,
@@ -161,7 +170,7 @@ timeVariation <- function(mydata,
                    ylab = quickText(ylab, auto.text),
                    xlab = xlab[2],
                    xlim = c(0, 23),
-                   ylim = rng(data.hour),
+                   ylim = ylim.hour,
                    strip = strip,
                    par.strip.text = list(cex = 0.8),
                    key = key,
@@ -194,6 +203,8 @@ timeVariation <- function(mydata,
 
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ weekday | ", temp, sep = ""))
+
+    if (missing(ylim)) ylim.weekday <- rng(data.weekday) else ylim.weekday <- ylim 
     
     day <- xyplot(myform,  data = data.weekday, groups = variable,
                   as.table = TRUE,
@@ -201,7 +212,7 @@ timeVariation <- function(mydata,
                   scales = list(x = list(at = 1:7, labels = format(ISOdate(2000, 1, 3:9), "%a"))),
                   ylab = quickText(ylab, auto.text),
                   xlab = xlab[4],
-                  ylim = rng(data.weekday),
+                  ylim = ylim.weekday,
                   strip = strip,
                   par.strip.text = list(cex = 0.8),
                   key = key,
@@ -231,12 +242,14 @@ timeVariation <- function(mydata,
 
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ month | ", temp, sep = ""))
+
+    if (missing(ylim)) ylim.month <-  rng(data.month) else ylim.month <- ylim 
     
     month <- xyplot(myform,  data = data.month, groups = variable,
                     as.table = TRUE,
                     ylab = quickText(ylab, auto.text),
                     xlab = xlab[3],
-                    ylim = rng(data.month),
+                    ylim = ylim.month,
                     xlim = c(0.5, 12.5),
                     key = key,
                     main = main,
@@ -295,12 +308,14 @@ timeVariation <- function(mydata,
     } else {
         myform <- formula(paste("Mean ~ hour | weekday *", temp, sep = ""))
     }
+
+    if (missing(ylim)) ylim.day.hour <-  rng(data.day.hour) else ylim.day.hour <- ylim 
     
     day.hour <- xyplot(myform ,  data = data.day.hour, groups = variable,
                        as.table = TRUE,
                        main = main,
                        xlim = c(0, 23),
-                       ylim = rng(data.day.hour),
+                       ylim = ylim.day.hour,
                        ylab = quickText(ylab, auto.text),
                        xlab = xlab[1],
                        layout = layout,
